function [OptFWHM,fnc] = RFT_FDR_Opt(lowsm_mgh, lowsm_contrastdir...
                               , avgdir , label, clust_th, qval, FWE, side)
% RFT_FDR_Opt.m
% Syntax:
%[OptFWHM,fnc] = RFT_FDR_Opt(lowsm_mgh, lowsm_statdir, avgdir...
%                                             , label, clust_th, qval, FWE)
%
%Determines the optimal FWHM and detection, and save a file with the name
%RFT_FDR_sig.mgh in the same directory as the freesurfer sig.mgh.
%//jbernal 2010.
%
%Arguments:
%lowsm_mgh: Complete path and name of the .mgh file containing the low
%smoothed data.
%lowsm_contrastdir: Directory of the freesurfer sig.mgh for the low
%smoothed data (known in freesurfer as 'glmdir/contrast name' ).
%avgdir: Directory of the freesurfer generated average subject for the
%study.
%label: Name of the label where the analysis is to be done. It must be in
%the average subject's label directory.
%clust_th: cluster-forming threshold.
%qval: FDR q-value.
%FWE: Family wise error.
%side: It is 0 for left-sided tests or 1 for right-sided tests or 2 for
%two-sided tests.
%
%Output:
%OptFWHM: Optimal FWHM. If empty then nothing has been detected with any
%smoothing.
%fnc: Values of the optimization function for FWHMs from 1 to 20.

%% Readings
%read low smoothed data
lowsm = SurfStatReadData(lowsm_mgh);
%low smoothed stat dir
inds = strfind(lowsm_contrastdir, '/');
lowsm_statdir = lowsm_contrastdir(1:inds(end)-1);
%read design matrix
fs_X = load([lowsm_statdir '/X.mat']);
%read contrast
fid = fopen([lowsm_contrastdir '/C.dat']);
tline = fgetl(fid);
fclose(fid);
contrast = fs_X.X*(str2num(tline)');
%read low smoothed SPM
[sig,Mvox2ras,mr_parms] = load_mgh([lowsm_contrastdir '/sig.mgh']);
%read label
[nv,vlabel] = ReadLabelData([avgdir '/label/' label]);
%hemisphere
if label(1) == 'l'
    hemi = 'lh';
else
    hemi = 'rh';
end;
%read average surf
avgsurf = SurfStatReadSurf([avgdir '/surf/', hemi, '.inflated'],'b');

%% Numerical optimization
fnc = zeros(1,20);
Optfnc = 0; OptFWHM = [];
smdata = lowsm;
display('We will smooth the data with FWHMs from 1mm to 20 mm in steps of 1mm!');
for k=1:20
   display([' smoothing with FWHM ', int2str(k)]);
   smdata = RecurrentSmooth(smdata,avgsurf,k);
   display(['Statistical analysis. RFT with cluster-forming threshold: '...
       , num2str(clust_th), ', FDR q-val: ', num2str(qval), ' and FWE: '...
       , num2str(FWE), ' ...']);
   %Hierarchical RFT-FDR correction
   [RFT_FDR_det, globalm0] = RFT_FDR(smdata, sig, avgsurf, fs_X.X...
                            , contrast, vlabel, clust_th, qval, FWE, side);
   ndet = length(RFT_FDR_det);
   fnc(k) = ndet*(1-qval)*(1-ndet*qval/globalm0);
   if fnc(k) > Optfnc
      Optfnc = fnc(k);
      OptFWHM = k;
      Optdet = RFT_FDR_det;
   end;
   display('Done');
end;
if isempty(OptFWHM)
   display('No se detectó nada');
else
   correct_sig = zeros(1,length(sig));
   correct_sig(Optdet+1) = sig(Optdet+1);         
   save_mgh(correct_sig,[lowsm_contrastdir '/RFT_FDR_sig.mgh'],Mvox2ras,mr_parms);
end;

